@@ -51,6 +51,8 @@
 
 
 
+static unsigned short SubroutineParamSize[0x10000];
+
 /*****************************************************************************/
 /*                             Helper functions                              */
 /*****************************************************************************/
@@ -741,3 +743,35 @@ void OH_JmpAbsoluteXIndirect (const OpcDesc* D)
     }
     SeparatorLine ();
 }
+
+
+
+void OH_JsrAbsolute (const OpcDesc* D)
+{
+    unsigned ParamSize = SubroutineParamSize[GetCodeWord (PC+1)];
+    OH_Absolute (D);
+    if (ParamSize > 0) {
+        unsigned RemainingBytes;
+        unsigned BytesLeft;
+        PC += D->Size;
+        RemainingBytes = GetRemainingBytes ();
+        if (RemainingBytes < ParamSize) {
+            ParamSize = RemainingBytes;
+        }
+        BytesLeft = ParamSize;
+        while (BytesLeft > 0) {
+            unsigned Chunk = (BytesLeft > BytesPerLine) ? BytesPerLine : BytesLeft;
+            DataByteLine (Chunk);
+            BytesLeft -= Chunk;
+            PC        += Chunk;
+        }
+        PC -= D->Size;
+    }
+}
+
+
+
+void SetSubroutineParamSize (unsigned Addr, unsigned Size)
+{
+    SubroutineParamSize[Addr] = Size;
+}
